@@ -7,8 +7,8 @@ from .diagnosis_form_validator import DiagnosesFormValidator
 from .histopathology_form_validator import HistopathologyFormValidator
 from .lp_csf_form_validator import LpCsfFormValidator
 from .medication_adherence_form_validator import MedicationAdherenceFormValidator
-from .medication_history_form_validator import MedicalHistoryFormValidator
 from .mental_status_form_validator import MentalStatusFormValidator
+from .patient_history_form_validator import PatientHistoryFormValidator
 from .patient_treatment_form_validator import PatientTreatmentFormValidator
 from .signs_and_symptoms_form_validator import SignsAndSymptomsFormValidator
 from .study_medication_baseline_form_validator import (
